@@ -1,6 +1,6 @@
-;;; mu4e-actions.el -- part of mu4e, the mu mail user agent -*- lexical-binding: t -*-
+;;; mu4e-actions.el --- Actions for messages/attachments -*- lexical-binding: t -*-
 
-;; Copyright (C) 2011-2021 Dirk-Jan C. Binnema
+;; Copyright (C) 2011-2023 Dirk-Jan C. Binnema
 
 ;; Author: Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
 ;; Maintainer: Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
@@ -27,21 +27,14 @@
 
 ;;; Code:
 
-(require 'cl-lib)
 (require 'ido)
+(require 'browse-url)
 
-(require 'mu4e-utils)
+(require 'mu4e-helpers)
 (require 'mu4e-message)
-(require 'mu4e-meta)
-
-(declare-function mu4e~proc-extract     "mu4e-proc")
-(declare-function mu4e-headers-search   "mu4e-headers")
-
-(defvar mu4e-headers-include-related)
-(defvar mu4e-headers-show-threads)
-(defvar mu4e-view-show-addresses)
-(defvar mu4e-view-date-format)
-
+(require 'mu4e-search)
+(require 'mu4e-contacts)
+(require 'mu4e-lists)
 
 ;;; Count lines
 
@@ -50,7 +43,8 @@
 Works for headers view and message-view."
   (message "Number of lines: %s"
            (shell-command-to-string
-            (concat "wc -l < " (shell-quote-argument (mu4e-message-field msg :path))))))
+            (concat "wc -l < "
+                    (shell-quote-argument (mu4e-message-field msg :path))))))
 
 ;;; Org Helpers
 
@@ -86,7 +80,8 @@ file where you store your org-contacts."
   (unless mu4e-org-contacts-file
     (mu4e-error "Variable `mu4e-org-contacts-file' is nil"))
   (let* ((sender (car-safe (mu4e-message-field msg :from)))
-         (name (car-safe sender)) (email (cdr-safe sender))
+         (name (mu4e-contact-name sender))
+         (email (mu4e-contact-email sender))
          (blurb
           (format
            (concat
@@ -103,28 +98,27 @@ file where you store your org-contacts."
           (append org-capture-templates
                   (list (list key "contacts" 'entry
                               (list 'file mu4e-org-contacts-file) blurb)))))
-    (message "%S" org-capture-templates)
     (when (fboundp 'org-capture)
       (org-capture nil key))))
 
 ;;; Patches
 
-(defvar mu4e~patch-directory-history nil
+(defvar mu4e--patch-directory-history nil
   "History of directories we have applied patches to.")
 
 ;; This essentially works around the fact that read-directory-name
 ;; can't have custom history.
-(defun mu4e~read-patch-directory (&optional prompt)
+(defun mu4e--read-patch-directory (&optional prompt)
   "Read a `PROMPT'ed directory name via `completing-read' with history."
   (unless prompt
     (setq prompt "Target directory:"))
   (file-truename
    (completing-read prompt 'read-file-name-internal #'file-directory-p
-                    nil nil 'mu4e~patch-directory-history)))
+                    nil nil 'mu4e--patch-directory-history)))
 
 (defun mu4e-action-git-apply-patch (msg)
   "Apply `MSG' as a git patch."
-  (let ((path (mu4e~read-patch-directory "Target directory: ")))
+  (let ((path (mu4e--read-patch-directory "Target directory: ")))
     (let ((default-directory path))
       (shell-command
        (format "git apply %s"
@@ -137,10 +131,10 @@ If the `default-directory' matches the most recent history entry don't
 bother asking for the git tree again (useful for bulk actions)."
 
   (let ((cwd (substring-no-properties
-              (or (car mu4e~patch-directory-history)
+              (or (car mu4e--patch-directory-history)
                   "not-a-dir"))))
     (unless (and (stringp cwd) (string= default-directory cwd))
-      (setq cwd (mu4e~read-patch-directory "Target directory: ")))
+      (setq cwd (mu4e--read-patch-directory "Target directory: ")))
     (let ((default-directory cwd))
       (shell-command
        (format "git am %s %s"
@@ -159,7 +153,7 @@ messages can lead to messages with multiple tags headers.")
 (defvar mu4e-action-tags-completion-list '()
   "List of tags for completion in `mu4e-action-retag-message'.")
 
-(defun mu4e~contains-line-matching (regexp path)
+(defun mu4e--contains-line-matching (regexp path)
   "Return non-nil if the file at PATH contain a line matching REGEXP.
 Otherwise return nil."
   (with-temp-buffer
@@ -168,14 +162,22 @@ Otherwise return nil."
       (goto-char (point-min))
       (re-search-forward regexp nil t))))
 
-(defun mu4e~replace-first-line-matching (regexp to-string path)
+(defun mu4e--replace-first-line-matching (regexp to-string path)
   "Replace first line matching REGEXP in PATH with TO-STRING."
   (with-temp-file path
     (insert-file-contents path)
     (save-excursion
       (goto-char (point-min))
       (if (re-search-forward regexp nil t)
-          (replace-match to-string nil nil)))))
+          (replace-match to-string t nil)))))
+
+(declare-function mu4e--server-add "mu4e-server")
+(defun mu4e--refresh-message (path)
+  "Re-parse message at PATH.
+if this works, we will
+receive (:info add :path <path> :docid <docid>) as well as (:update
+<msg-sexp>)."
+  (mu4e--server-add path))
 
 (defun mu4e-action-retag-message (msg &optional retag-arg)
   "Change tags of MSG with RETAG-ARG.
@@ -183,7 +185,7 @@ Otherwise return nil."
 RETAG-ARG is a comma-separated list of additions and removals.
 
 Example: +tag,+long tag,-oldtag
-would add 'tag' and 'long tag', and remove 'oldtag'."
+would add \"tag\" and \"long tag\", and remove \"oldtag\"."
   (let* (
          (path (mu4e-message-field msg :path))
          (oldtags (mu4e-message-field msg :tags))
@@ -219,19 +221,19 @@ would add 'tag' and 'long tag', and remove 'oldtag'."
     (setq tagstr (replace-regexp-in-string "[\\&]" "\\\\\\&" tagstr))
     (setq tagstr (replace-regexp-in-string "[/]"   "\\&" tagstr))
 
-    (if (not (mu4e~contains-line-matching (concat header ":.*") path))
+    (if (not (mu4e--contains-line-matching (concat header ":.*") path))
         ;; Add tags header just before the content
-        (mu4e~replace-first-line-matching
+        (mu4e--replace-first-line-matching
          "^$" (concat header ": " tagstr "\n") path)
 
       ;; replaces keywords, restricted to the header
-      (mu4e~replace-first-line-matching
+      (mu4e--replace-first-line-matching
        (concat header ":.*")
        (concat header ": " tagstr)
        path))
 
     (mu4e-message (concat "tagging: " (mapconcat 'identity taglist ", ")))
-    (mu4e-refresh-message path)))
+    (mu4e--refresh-message path)))
 
 (defun mu4e-action-show-thread (msg)
   "Show thread for message at point with point remaining on MSG.
@@ -240,14 +242,34 @@ action was invoked. If invoked in view mode, continue to display
 the message."
   (let ((msgid (mu4e-message-field msg :message-id)))
     (when msgid
-      (let ((mu4e-headers-show-threads t)
-            (mu4e-headers-include-related t))
-        (mu4e-headers-search
+      (let ((mu4e-search-threads t)
+            (mu4e-search-include-related t))
+        (mu4e-search
          (format "msgid:%s" msgid)
          nil nil nil
          msgid (and (eq major-mode 'mu4e-view-mode)
                     (not (eq mu4e-split-view 'single-window))))))))
 
-;;; _
+
+;;; Mailing list URLS
+
+(defun mu4e-action-browse-list-archive (msg)
+  "Browse the archive for a mailing list message MSG.
+See `mu4e-mailing-list-archive-url'."
+  (interactive (list (mu4e-message-at-point)))
+  (if-let ((url (mu4e-mailing-list-archive-url msg)))
+    (browse-url url)
+    (mu4e-warn "No archive available for this message")))
+
+(defun mu4e-action-copy-list-archive-url (msg)
+  "Copy the archive url for a mailing list message MSG.
+See `mu4e-mailing-list-archive-url'."
+  (interactive (list (mu4e-message-at-point)))
+  (let ((url (mu4e-mailing-list-archive-url msg)))
+    (if (stringp url)
+        (kill-new url)
+      (mu4e-warn "Cannot get archive URL for this message"))))
+
+;;;
 (provide 'mu4e-actions)
 ;;; mu4e-actions.el ends here
