@@ -1,6 +1,6 @@
-;;; mu4e-message.el -- part of mu4e -*- lexical-binding: t -*-
+;;; mu4e-message.el --- Working with mu4e-message plists -*- lexical-binding: t -*-
 
-;; Copyright (C) 2012-2022 Dirk-Jan C. Binnema
+;; Copyright (C) 2012-2024 Dirk-Jan C. Binnema
 
 ;; Author: Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
 ;; Maintainer: Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
@@ -28,21 +28,15 @@
 
 (require 'mu4e-vars)
 (require 'mu4e-contacts)
+(require 'mu4e-window)
+(require 'mu4e-helpers)
 (require 'flow-fill)
 (require 'shr)
 (require 'pp)
 
-(declare-function mu4e-error "mu4e-helpers")
-(declare-function mu4e-warn  "mu4e-helpers")
-(declare-function mu4e-personal-address-p "mu4e-contacts")
-(declare-function mu4e-make-temp-file  "mu4e-helpers")
 
-(make-obsolete-variable 'mu4e-html2text-command "No longer in use" "1.7.0")
-(make-obsolete-variable 'mu4e-view-prefer-html "No longer in use" "1.7.0")
-(make-obsolete-variable 'mu4e-view-html-plaintext-ratio-heuristic
-			"No longer in use" "1.7.0")
-(make-obsolete-variable 'mu4e-message-body-rewrite-functions
-			"No longer in use" "1.7.0")
+(declare-function mu4e-determine-attachment-dir  "mu4e-helpers")
+(declare-function mu4e-personal-address-p "mu4e-contacts")
 
 ;;; Message fields
 
@@ -116,7 +110,7 @@ no such message. If optional NOERROR is non-nil, do not raise an
 error when there is no message at point."
   (or (cond
        ((eq major-mode 'mu4e-headers-mode) (get-text-property (point) 'msg))
-       ((eq major-mode 'mu4e-view-mode) mu4e~view-message))
+       ((eq major-mode 'mu4e-view-mode) mu4e--view-message))
       (unless noerror (mu4e-warn "No message at point"))))
 
 (defsubst mu4e-message-field-at-point (field)
@@ -148,7 +142,7 @@ expressions, in which case any of those are tried for a match."
     (seq-find
      (lambda (ct)
        (let ((name (mu4e-contact-name ct))
-	     (email (mu4e-contact-email ct))
+             (email (mu4e-contact-email ct))
              ;; the 'rx' may be some `/rx/` from mu4e-personal-addresses;
              ;; so let's detect and extract in that case.
              (rx (if (string-match-p  "^\\(.*\\)/$" rx)
@@ -166,7 +160,7 @@ of the of the contacts in field CFIELD (either :to, :from, :cc or
 which `mu4e-personal-address-p' return t. Returns the contact
 cell that matched, or nil."
   (seq-find (lambda (cell)
-	      (mu4e-personal-address-p (mu4e-contact-email cell)))
+              (mu4e-personal-address-p (mu4e-contact-email cell)))
             (mu4e-message-field msg cfield)))
 
 (defun mu4e-message-sent-by-me (msg)
@@ -198,9 +192,6 @@ Either in the headers buffer or the view buffer. Field is a
 symbol, see `mu4e-header-info'."
   (plist-get (mu4e-message-at-point) field))
 
-;;; Html2Text
-(make-obsolete 'mu4e-shr2text "No longer in use" "1.7.0")
-
 (defun mu4e-message-readable-path (&optional msg)
   "Get a readable path to MSG or raise an error.
 If MSG is nil, use `mu4e-message-at-point'."
@@ -216,8 +207,33 @@ If MSG is nil, use `mu4e-message-at-point'."
     (kill-new path)
     (mu4e-message "Saved '%s' to kill-ring" path)))
 
-(defconst mu4e--sexp-buffer-name " *mu4e-sexp-at-point"
-  "Buffer name for sexp buffers.")
+(defun mu4e-save-message (&optional auto-path auto-overwrite)
+  "Save a copy of the message-at-point.
+
+If AUTO-PATH is non-nil, save to the attachment directory for
+message/rfc822 files as per `mu4e-determine-attachment-dir'.
+Otherwise, ask user.
+
+If AUTO-OVERWRITE is non-nil, automatically overwrite if a file
+with the same name already exist in the target directory.
+Otherwise, ask for user confirmation.
+
+Returns the full path."
+  (interactive "P")
+  (let* ((srcpath (mu4e-message-readable-path))
+         (srcname (file-name-nondirectory srcpath))
+         (destdir (file-name-as-directory
+                   (mu4e-determine-attachment-dir
+                    srcpath "message/rfc822")))
+         (destpath (mu4e-join-paths destdir srcname))
+         (destpath
+          (if auto-path destpath
+              (read-file-name "Save message as: "
+                              destdir nil nil srcname))))
+    (when destpath
+      (copy-file srcpath destpath (if auto-overwrite t 0))
+      (mu4e-message "Saved %s" destpath)
+      destpath)))
 
 (defun mu4e-sexp-at-point ()
   "Show or hide the s-expression for the message-at-point, if any."
@@ -225,9 +241,35 @@ If MSG is nil, use `mu4e-message-at-point'."
   (if-let ((win (get-buffer-window mu4e--sexp-buffer-name)))
       (delete-window win)
     (when-let ((msg (mu4e-message-at-point 'noerror)))
-      (with-current-buffer-window mu4e--sexp-buffer-name nil nil
-	;; the "pretty-printing" is not very pretty...
-	(insert (pp-to-string msg))))))
+      (when (buffer-live-p mu4e--sexp-buffer-name)
+        (kill-buffer mu4e--sexp-buffer-name))
+      (with-current-buffer-window
+          (get-buffer-create mu4e--sexp-buffer-name) nil nil
+        (if (fboundp 'lisp-data-mode)
+            (lisp-data-mode)
+          (lisp-mode))
+        (insert (pp-to-string msg))
+        (font-lock-ensure)
+        ;; add basic `quit-window' bindings
+        (view-mode 1)))))
+
+(declare-function mu4e--decoded-message "mu4e-compose")
+
+(defun mu4e-fetch-field (msg hdr &optional first)
+  "Find the value for an arbitrary header field HDR from MSG.
+
+If the header appears multiple times, the field values are
+concatenated, unless FIRST is non-nil, in which case only the
+first value is returned. See `message-field-value' and
+`nessage-fetch-field' for details.
+
+Note: this loads the full message file such that any available
+message header can be used. If the header is part of the MSG
+plist, it is much more efficient to get the information from that
+plist."
+  (with-temp-buffer
+    (insert (mu4e--decoded-message msg 'headers-only))
+    (message-field-value hdr first)))
 
 ;;;
 (provide 'mu4e-message)
